# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/50_path.ipynb.

# %% auto 0
__all__ = ['DIR', 'LOC', 'SRC', 'BASE', 'DEST', 'FILE', 'PATH', 'ROOT', 'NODE', 'ROOT_DIR', 'PREP_PATH', 'NBS', 'FIG', 'IMG',
           'RES', 'DATA', 'FIGS', 'IMGS', 'FIGURES', 'RESULTS', 'EXAMPLES', 'RB', 'WB', 'NT', 'POSIX', 'WINDOWS',
           'CLIP', 'ECHO', 'HEAD', 'TAIL', 'PBCOPY', 'SYMLINK', 'HARDLINK', 'METADATA', 'CORE', 'FLDR', 'LEAF', 'REST',
           'PathKind', 'EntryType', 'OSType', 'PathLibType']

# %% ../nbs/50_path.ipynb 4
import os
from enum import Enum, StrEnum
from pathlib import (Path, PosixPath, WindowsPath)

# %% ../nbs/50_path.ipynb 5
from .args import PREP

# %% ../nbs/50_path.ipynb 7
DIR = 'dir'
LOC = 'loc'
SRC = 'src'

BASE = 'base'
DEST = 'dest'

FILE = 'file'

PATH = 'path'
ROOT = 'root'

NODE = 'node'

# %% ../nbs/50_path.ipynb 8
ROOT_DIR = f'{ROOT}_{DIR}'

# %% ../nbs/50_path.ipynb 9
PREP_PATH = f'{PREP}_{PATH}'

# %% ../nbs/50_path.ipynb 11
class PathKind(StrEnum):
    DIR  = DIR
    FILE = FILE
    PATH = PATH
    @classmethod
    def kinds(cls) -> set: return set(m.value for m in cls)   

# %% ../nbs/50_path.ipynb 12
class EntryType(StrEnum):
    DIR  = DIR
    FILE = FILE
    PATH = PATH
    @classmethod
    def kinds(cls) -> set: return set(m.value for m in cls)   

# %% ../nbs/50_path.ipynb 14
NBS = 'nbs'

FIG = 'fig'
IMG = 'img'
RES = 'res'

# %% ../nbs/50_path.ipynb 15
DATA = 'data'

FIGS = f'{FIG}s'
IMGS = f'{IMG}s'

FIGURES = f'{FIG}ures'
RESULTS = f'{RES}ults'

EXAMPLES = 'examples'

# %% ../nbs/50_path.ipynb 17
RB = 'rb'
WB = 'wb'

# %% ../nbs/50_path.ipynb 19
NT = 'nt'
POSIX = 'posix'
WINDOWS = 'windows'

# %% ../nbs/50_path.ipynb 21
class OSType(StrEnum):
    NT  = NT
    POSIX = POSIX
    WINDOWS = WINDOWS

    def __str__(self) -> str: return str(self.value).casefold()

    @classmethod
    def osname(cls, obj: 'OSType' = os): 
        return str(getattr(obj, 'name', os.name)).casefold()
    
    @classmethod
    def ostype(cls, obj: 'OSType' = os) -> Path: 
        return PosixPath if cls.osname(obj) == POSIX else WindowsPath
    
    @classmethod
    def oscomp(cls, oshave: 'OSType' = None, oswant: 'OSType' = None) -> bool: 
        return str(oshave) == str(cls.ostype(oswant))
    
    @classmethod
    def is_psx(cls, osn: 'OSType' = None) -> bool: return cls.oscomp(cls.ostype(osn), cls.POSIX)

    @classmethod
    def is_wdx(cls, osn: 'OSType' = None) -> bool: return cls.oscomp(cls.ostype(osn), cls.WINDOWS) 

    @classmethod
    def pathlib_type(cls, osname: 'OSType' = None) -> Path:
        return PosixPath if cls.is_psx(osname) else WindowsPath

    @classmethod
    def addcls(cls, pathclass):
        pathtype = cls.pathlib_type(pathclass)
        for kls in (PosixPath, WindowsPath, ):
            if pathtype in kls.__bases__: continue
            kls.value.__bases__ += (pathtype, )

# %% ../nbs/50_path.ipynb 23
class PathLibType(Enum):
    POSIX = PosixPath
    WINDOWS = WindowsPath
    
    def __str__(self) -> str: return str(self.name).casefold()

    @classmethod
    def addcls(cls, pthcls):
        for member in cls:
            if pthcls in member.value.__bases__: continue
            member.value.__bases__ += (pthcls, )

    @classmethod
    def pthcls(cls, osname: OSType = None) -> Path:
        return PosixPath if OSType.is_psx(osname) else WindowsPath


# %% ../nbs/50_path.ipynb 25
CLIP = 'clip'
ECHO = 'echo'
HEAD = 'head'
TAIL = 'tail'
PBCOPY = 'pbcopy'

# %% ../nbs/50_path.ipynb 27
SYMLINK = 'symlink'
HARDLINK = 'hardlink'
METADATA = 'metadata'

# %% ../nbs/50_path.ipynb 30
CORE = 'core'
FLDR = 'fldr'
LEAF = 'leaf'
REST = 'rest'

# %% ../nbs/50_path.ipynb 31
BDIR = f'b{DIR}' # base
CDIR = f'c{DIR}' # curr
DDIR = f'd{DIR}' # dest
EDIR = f'e{DIR}' # expanded
FDIR = f'f{DIR}' # file
HDIR = f'h{DIR}' # hidden
QDIR = f'q{DIR}' # 
RDIR = f'r{DIR}' # root / relative
PDIR = f'p{DIR}' # path dir
XDIR = f'x{DIR}' # 

# %% ../nbs/50_path.ipynb 33
BLOC = f'b{LOC}'
CLOC = f'c{LOC}'
DLOC = f'd{LOC}'
ELOC = f'e{LOC}'
FLOC = f'f{LOC}'
HLOC = f'h{LOC}'
QLOC = f'q{LOC}'
RLOC = f'r{LOC}'
PLOC = f'p{LOC}'
XLOC = f'x{LOC}'

# %% ../nbs/50_path.ipynb 35
BSRC = f'b{SRC}'
CSRC = f'c{SRC}'
DSRC = f'd{SRC}'
ESRC = f'e{SRC}'
FSRC = f'f{SRC}'
HSRC = f'h{SRC}'
QSRC = f'q{SRC}'
RSRC = f'r{SRC}'
PSRC = f'p{SRC}'
XSRC = f'x{SRC}'



# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/nlit',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/nlit',
                'lib_path': 'nlit'},
  'syms': { 'nlit.args': {},
            'nlit.attr': {},
            'nlit.biol': {'nlit.biol.AnnPart': ('biol.html#annpart', 'nlit/biol.py')},
            'nlit.bkts': {},
            'nlit.byte': {},
            'nlit.cell': {},
            'nlit.clrs': {},
            'nlit.dict': {},
            'nlit.docs': {},
            'nlit.dund': {},
            'nlit.embs': {},
            'nlit.errs': {},
            'nlit.expo': { 'nlit.expo.Expo': ('expo.html#expo', 'nlit/expo.py'),
                           'nlit.expo.ExpoInfo': ('expo.html#expoinfo', 'nlit/expo.py')},
            'nlit.exps': {},
            'nlit.exts': {},
            'nlit.fmtx': {'nlit.fmtx.FilteredMatrixFile': ('fmtx.html#filteredmatrixfile', 'nlit/fmtx.py')},
            'nlit.hrdw': {},
            'nlit.math': {},
            'nlit.mods': {},
            'nlit.mthd': {},
            'nlit.narr': {},
            'nlit.nbks': {},
            'nlit.path': { 'nlit.path.EntryType': ('path.html#entrytype', 'nlit/path.py'),
                           'nlit.path.EntryType.kinds': ('path.html#entrytype.kinds', 'nlit/path.py'),
                           'nlit.path.OSType': ('path.html#ostype', 'nlit/path.py'),
                           'nlit.path.OSType.__str__': ('path.html#ostype.__str__', 'nlit/path.py'),
                           'nlit.path.OSType.addcls': ('path.html#ostype.addcls', 'nlit/path.py'),
                           'nlit.path.OSType.is_psx': ('path.html#ostype.is_psx', 'nlit/path.py'),
                           'nlit.path.OSType.is_wdx': ('path.html#ostype.is_wdx', 'nlit/path.py'),
                           'nlit.path.OSType.oscomp': ('path.html#ostype.oscomp', 'nlit/path.py'),
                           'nlit.path.OSType.osname': ('path.html#ostype.osname', 'nlit/path.py'),
                           'nlit.path.OSType.ostype': ('path.html#ostype.ostype', 'nlit/path.py'),
                           'nlit.path.OSType.pathlib_type': ('path.html#ostype.pathlib_type', 'nlit/path.py'),
                           'nlit.path.PathKind': ('path.html#pathkind', 'nlit/path.py'),
                           'nlit.path.PathKind.kinds': ('path.html#pathkind.kinds', 'nlit/path.py'),
                           'nlit.path.PathLibType': ('path.html#pathlibtype', 'nlit/path.py'),
                           'nlit.path.PathLibType.__str__': ('path.html#pathlibtype.__str__', 'nlit/path.py'),
                           'nlit.path.PathLibType.addcls': ('path.html#pathlibtype.addcls', 'nlit/path.py'),
                           'nlit.path.PathLibType.pthcls': ('path.html#pathlibtype.pthcls', 'nlit/path.py')},
            'nlit.pddf': {},
            'nlit.pkgs': {},
            'nlit.plot': {},
            'nlit.sund': {},
            'nlit.tens': {},
            'nlit.tree': {},
            'nlit.unit': {},
            'nlit.vals': {},
            'nlit.vers': {}}}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/09_dict.ipynb.

# %% auto 0
__all__ = ['KEY', 'GET', 'VAL', 'DICT', 'PTTN_DICT']

# %% ../nbs/09_dict.ipynb 4
from .args import PTTN

# %% ../nbs/09_dict.ipynb 6
KEY = 'key'
GET = 'get'
VAL = 'val'

DICT = 'dict'


PTTN_DICT = f'{PTTN}_{DICT}'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/90_unit.ipynb.

# %% auto 0
__all__ = ['ONE', 'TEN', 'HUNDRED', 'THOUSAND', 'MILLION', 'BILLION', 'TRILLION', 'QUADRILLION', 'QUINTILLION', 'SEXTILLION',
           'SEPTILLION', 'OCTILLION', 'NONILLION', 'TENTH', 'HUNDREDTH', 'THOUSANDTH', 'MILLIONTH', 'BILLIONTH',
           'TRILLIONTH', 'QUADRILLIONTH', 'QUINTILLIONTH', 'SEXTILLIONTH', 'SEPTILLIONTH', 'OCTILLIONTH', 'NONILLIONTH',
           'DECA', 'HECTO', 'KILO', 'MEGA', 'GIGA', 'TERA', 'PETA', 'EXA', 'ZETTA', 'YOTTA', 'RONNA', 'QUETTA', 'DECI',
           'CENTI', 'MILLI', 'MICRO', 'NANO', 'PICO', 'FEMTO', 'ATTO', 'ZEPTO', 'YOCTO', 'RONTO', 'QUECTO', 'da', 'h',
           'k', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y', 'R', 'Q', 'd', 'c', 'm', 'u', 'n', 'p', 'f', 'a', 'z', 'y', 'r', 'q',
           'POS_NAMES', 'NEG_NAMES', 'UNIT_NAMES', 'POS_ABRVS', 'NEG_ABRVS', 'UNIT_ABRVS', 'POS_SYMBS', 'NEG_SYMBS',
           'UNIT_SYMBS']

# %% ../nbs/90_unit.ipynb 6
ONE = 'one'

TEN = 'ten'
HUNDRED = 'hundred'
THOUSAND = 'thousand'
MILLION = 'million'
BILLION = 'billion'
TRILLION = 'trillion'
QUADRILLION = 'quadrillion'
QUINTILLION = 'quintillion'
SEXTILLION = 'sextillion'
SEPTILLION = 'septillion'
OCTILLION = 'octillion'
NONILLION = 'nonillion'

TENTH = 'tenth'
HUNDREDTH = 'hundredth'
THOUSANDTH = 'thousandth'
MILLIONTH = 'millionth'
BILLIONTH = 'billionth'
TRILLIONTH = 'trillionth'
QUADRILLIONTH = 'quadrillionth'
QUINTILLIONTH = 'quintillionth'
SEXTILLIONTH = 'sextillionth'
SEPTILLIONTH = 'septillionth'
OCTILLIONTH = 'octillionth'
NONILLIONTH = 'nonillionth'

# %% ../nbs/90_unit.ipynb 8
DECA = 'deca'
HECTO = 'hecto'
KILO = 'kilo'
MEGA = 'mega'
GIGA = 'giga'
TERA = 'tera'
PETA = 'peta'
EXA = 'exa'
ZETTA = 'zetta'
YOTTA = 'yotta'
RONNA = 'ronna'
QUETTA = 'quetta'

DECI = 'deci'
CENTI = 'centi'
MILLI = 'milli'
MICRO = 'micro'
NANO = 'nano'
PICO = 'pico'
FEMTO = 'femto'
ATTO = 'atto'
ZEPTO = 'zepto'
YOCTO = 'yocto'
RONTO = 'ronto'
QUECTO = 'quecto'

# %% ../nbs/90_unit.ipynb 10
da = 'da'
h = 'h'
k = 'k'
M = 'M'
G = 'G'
T = 'T'
P = 'P'
E = 'E'
Z = 'Z'
Y = 'Y'
R = 'R'
Q = 'Q'
d = 'd'
c = 'c'
m = 'm'
u = 'u'
n = 'n'
p = 'p'
f = 'f'
a = 'a'
z = 'z'
y = 'y'
r = 'r'
q = 'q'

# %% ../nbs/90_unit.ipynb 13
POS_NAMES = (
    TEN, HUNDRED, THOUSAND, MILLION, BILLION, TRILLION, 
    QUADRILLION, QUINTILLION, SEXTILLION, SEPTILLION, OCTILLION, NONILLION
)

NEG_NAMES = (
    TENTH, HUNDREDTH, THOUSANDTH, MILLIONTH, BILLIONTH, TRILLIONTH, 
    QUADRILLIONTH, QUINTILLIONTH, SEXTILLIONTH, SEPTILLIONTH, OCTILLIONTH, NONILLIONTH
)

UNIT_NAMES = (ONE, ) + POS_NAMES + NEG_NAMES

# %% ../nbs/90_unit.ipynb 15
POS_ABRVS = (
    DECA, HECTO, KILO, MEGA, GIGA, TERA, PETA, EXA, ZETTA, YOTTA, RONNA, QUETTA
)
NEG_ABRVS = (
    DECI, CENTI, MILLI, MICRO, NANO, PICO, FEMTO, ATTO, ZEPTO, YOCTO, RONTO, QUECTO
)

UNIT_ABRVS = (None, ) + POS_ABRVS + NEG_ABRVS

# %% ../nbs/90_unit.ipynb 17
POS_SYMBS = (da, h, k, M, G, T, P, E, Z, Y, R, Q)
NEG_SYMBS = (d, c, m, u, n, p, f, a, z, y, r, q)

UNIT_SYMBS = (None, ) + POS_SYMBS +  NEG_SYMBS



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/62_pddf.ipynb.

# %% auto 0
__all__ = ['DF', 'DS', 'DATA', 'DATASET', 'DATAFRAME', 'IDX', 'INDEX', 'CAT', 'CATEGORY', 'CATEGORIES', 'COL', 'COLS', 'COLUMNS',
           'GET', 'SHAPE']

# %% ../nbs/62_pddf.ipynb 5
DF = 'df'
DS = 'ds'
DATA = 'data'
DATASET = f'{DATA}set'
DATAFRAME = f'{DATA}frame'

# %% ../nbs/62_pddf.ipynb 6
IDX = 'idx'
INDEX = 'index'

# %% ../nbs/62_pddf.ipynb 7
CAT = 'cat'
CATEGORY = f'{CAT}egory'
CATEGORIES = f'{CAT}egories'

# %% ../nbs/62_pddf.ipynb 8
COL = 'col'
COLS = f'{COL}s'
COLUMNS = f'{COL}umns'

# %% ../nbs/62_pddf.ipynb 9
GET = 'get'
SHAPE = f'shape'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/40_biol.ipynb.

# %% auto 0
__all__ = ['OBS', 'VAR', 'OBSM', 'VARM', 'OBSP', 'VARP', 'UNS', 'LAYER', 'LAYERS', 'MITO', 'RIBO', 'CELL', 'CELLS', 'BARCODE',
           'BARCODES', 'GENE', 'GENES', 'N_GENES', 'GENE_ID', 'GENE_IDS', 'GENE_SYMBOL', 'HVG', 'HIGHLY_VARIABLE',
           'COUNTS', 'TOTAL_COUNTS', 'N_GENES_BY_COUNTS', 'LOG1P_TOTAL_COUNTS', 'ENS', 'ENSG', 'ENSEMBL', 'ENSEMBL_ID',
           'DOUBLET', 'DOUBLET_SCORES', 'PREDICTED_DOUBLETS', 'HUMAN', 'MOUSE', 'HUMAN_TF', 'MOUSE_TF',
           'HUMAN_GENE_SYMBOL', 'HUMAN_ENSEMBLE_ID', 'MOUSE_ENSEMBLE_ID', 'PRENORM', 'DETECTED', 'SCALED_NORMALIZED',
           'PCT_COUNTS', 'PCT_COUNTS_MITO', 'PCT_COUNTS_RIBO', 'X', 'X_', 'X_PRENORM', 'X_DETECTED',
           'X_SCALED_NORMALIZED', 'PCA_HVG', 'MAGIC_HVG', 'PHATE_HVG', 'ADATA', 'MATRIX', 'FEATURES', 'SENSITIVITY',
           'FILTERED_MATRIX', 'SEQ', 'SEQRUN', 'SEQRUNS', 'FIRST_SENS', 'UNIQUE_SENS', 'UNIQUE_SENSITIVITY',
           'UNIQUE_SENSITIVITIES', 'AnnPart']

# %% ../nbs/40_biol.ipynb 4
from enum import StrEnum

# %% ../nbs/40_biol.ipynb 5
from nchr import U1
from .args import UNIQUE
from .exps import ID, PCT, SENS, SENSITIVITIES, NORMALIZED, COUNT, TOTAL
from .mthd import MAGIC, PCA, PHATE, LOG1P
from .exts import EXT_H5, EXT_H5AD, EXT_MTX, EXT_TSV

# %% ../nbs/40_biol.ipynb 8
OBS = 'obs'
VAR = 'var'

OBSM = f'{OBS}m'
VARM = f'{VAR}m'

OBSP = f'{OBS}p'
VARP = f'{VAR}p'

UNS = 'uns'

LAYER = 'layer'
LAYERS = f'{LAYER}s'

# %% ../nbs/40_biol.ipynb 10
MITO = 'mito'
RIBO = 'ribo'

# %% ../nbs/40_biol.ipynb 11
CELL = 'cell'
CELLS = f'{CELL}s'

# %% ../nbs/40_biol.ipynb 12
BARCODE = 'barcode'
BARCODES = f'{BARCODE}s'

# %% ../nbs/40_biol.ipynb 14
GENE = 'gene'
GENES = f'{GENE}s'
N_GENES = f'n_{GENES}'

GENE_ID = f'{GENE}{U1}{ID}'
GENE_IDS = f'{GENE_ID}s'
GENE_SYMBOL = f'{GENE}{U1}symbol'

# %% ../nbs/40_biol.ipynb 16
HVG = 'hvg'
HIGHLY_VARIABLE = 'highly_variable'

# %% ../nbs/40_biol.ipynb 18
COUNTS = f'{COUNT}s'
TOTAL_COUNTS = f'{TOTAL}{U1}{COUNTS}'

# %% ../nbs/40_biol.ipynb 20
N_GENES_BY_COUNTS = f'{N_GENES}_by_{COUNTS}'
LOG1P_TOTAL_COUNTS = f'{LOG1P}{U1}{TOTAL_COUNTS}'

# %% ../nbs/40_biol.ipynb 22
ENS = 'ens'
ENSG = f'{ENS}g'
ENSEMBL = 'ensembl'
ENSEMBL_ID = f'{ENSEMBL}{U1}{ID}'

# %% ../nbs/40_biol.ipynb 24
DOUBLET = 'doublet'
DOUBLET_SCORES = f'{DOUBLET}_scores'
PREDICTED_DOUBLETS = f'predicted_{DOUBLET}s'

# %% ../nbs/40_biol.ipynb 26
HUMAN = 'human'
MOUSE = 'mouse'

HUMAN_TF = f'{HUMAN}TFs'
MOUSE_TF = f'{MOUSE}TFs'

HUMAN_GENE_SYMBOL = f'{HUMAN}GeneSymbol'
HUMAN_ENSEMBLE_ID = f'{HUMAN}EnsemblID'
MOUSE_ENSEMBLE_ID = f'{MOUSE}EnsemblID'

PRENORM = 'prenorm'
DETECTED = 'detected'

SCALED_NORMALIZED = f'scaled_{NORMALIZED}'

PCT_COUNTS = f'{PCT}{U1}{COUNTS}'
PCT_COUNTS_MITO = f'{PCT}{U1}{COUNTS}{U1}{MITO}'
PCT_COUNTS_RIBO = f'{PCT}{U1}{COUNTS}{U1}{RIBO}'

# %% ../nbs/40_biol.ipynb 28
X = 'X'
X_ = f'{X}{U1}'

# %% ../nbs/40_biol.ipynb 29
# Layer storing prenormalized counts in adata.layers
X_PRENORM = f'{X_}{PRENORM}'

# Layer storing values where prenormalized counts is at least 0 in adata.layers
X_DETECTED = f'{X_}{DETECTED}'

# Layer storing counts normalized
X_SCALED_NORMALIZED = f'{X_}{SCALED_NORMALIZED}'

# %% ../nbs/40_biol.ipynb 31
PCA_HVG = f'{PCA}{U1}{HVG}'
MAGIC_HVG = f'{MAGIC}{U1}{HVG}'
PHATE_HVG = f'{PHATE}{U1}{HVG}'

# %% ../nbs/40_biol.ipynb 33
ADATA = 'adata'

MATRIX = 'matrix'

FEATURES = 'features'

SENSITIVITY = 'sensitivity'

FILTERED_MATRIX = 'filtered_matrix'

# %% ../nbs/40_biol.ipynb 34
class AnnPart(StrEnum):
    X = X
    OBS = OBS
    OBSM = OBSM
    OBSP = OBSP
    VAR = VAR
    VARM = VARM
    VARP = VARP
    UNS = UNS
    LAYERS = LAYERS

# %% ../nbs/40_biol.ipynb 36
SEQ = 'seq'
SEQRUN = f'{SEQ}run'
SEQRUNS = f'{SEQRUN}s'

# %% ../nbs/40_biol.ipynb 37
FIRST_SENS = f'first{U1}{SENS}'
UNIQUE_SENS = f'{UNIQUE}{U1}{SENS}'
UNIQUE_SENSITIVITY = f'{UNIQUE}{U1}{SENSITIVITY}'
UNIQUE_SENSITIVITIES = f'{UNIQUE}{U1}{SENSITIVITIES}'
